==> Sections-1.0.1.zip: lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'Секции';
$lang['postinstall'] = 'Модуль "Секции" успешно установлен!';
$lang['postuninstall'] = 'Модуль "Секции" успешно удалён!';
$lang['really_uninstall'] = 'Вы уверены, что хотите удалить модуль "Секции"?';
$lang['uninstalled'] = 'Удалён модуль "Секции".';
$lang['installed'] = 'Установлен модуль "Секции" - версия %s.';
$lang['moddescription'] = 'Секции - это блоки контента, которые вы можете размещать в своих шаблонах и страницах с помощью \'плейсхолдеров\'.';
$lang['help'] = '
<h3>Для чего нужен этот модуль?</h3>
<p>Данный модуль позволяет создавать секции, в которые Вы можете помещать любой контент, будь то просто текст или html-содержимое или js-код.</p>
<p>Вы можете вставить тег данного модуля в шаблон и при редактировании секции на вкладке "Условия показа" выбрать страницы на которых данная секция будет видна.</p>
<p>Это может быть полезно, если вы хотите показывать в одном и том же месте на странице разное содержание, но не хотите выносить этот блок в область контента страницы.</p>
<p>Также Вы можете выставить у секции дату начала показа и дату окончания показа. Выставление этих параметров будет означать, что секция будет отображаться только в заданном промежутке времени и Вам не нужно беспокоится о выключении тех или иных секций в определённые дни.</p>
<h3>Как использовать модуль?</h3>
<p>После создания секции вставьте плейсхолдер секции вида {Sections name=\'internal_name\'} в шаблон, в страницу или куда-либо ещё, где internal_name это "Внутреннее имя" секции и при просмотре на месте плейсхолдера будет содержимое данной секции.</p>
<h4>Условный показ</h4>
<h5>Выбор промежутка дат для показа</h5>
<p>Вы можете выбрать дату начала показа и дату окончания показа. В случае если оба числа выбраны, секция будет показываться только в данном промежутке дат.</p>
<h5>Выбор страниц для показа</h5>
<p>Если вы вставите секцию в шаблон, то по умолчанию она будет показываться на всех страницах у которых выбран данный шаблон. Однако, если при редактировании секции во вкладке "Условия показа" Вы выберете страницы на которых вы хотите видеть секцию, то она будет показываться только на этих страницах.</p>
<p>Также, для удобства, Вы можете наоборот выбрать те страницы на которых секция показываться не должна.</p>
<h3>Обработка тегов(плейсхолдеров) в контенте секции</h3>
<p>В контенте секции Вы можете использовать все теги и теги пользователя.</p>
<p>К сожалению поддержки тегов модулей нет. Это значит, что Вы не можете использовать такие теги как {search}, {menu} или {news}.</p>
<p>Проверяйте работоспособность секции, если вставляете в неё какой-либо тег.</p>
<h3>Использование в JavaScript</h3>
<p>Использовать секции в JavaScript очень просто. Для этого нужно проделать всего несколько шагов.</p>
<ol>
<li>Создать шаблон в который поместить только тег {content}. К примеру его можно назвать "_system_".</li>
<li>Создать секцию, поместить в неё тот контент, который требуется получить через JavaScript.</li>
<li>Создать страницу и присвоить ей шаблон _system_. В качестве контента указать тег секции вида {Sections name=\'internal_name\' format=\'json\'}. Параметр \'format\' указывает в каком виде возвращать данные. Если указать json, то контент секции будет возвращён в json формате, если указать default, то контент секции будет возвращён в обычном html формате.</li>
</ol>
<p>Теперь Вы можете получить содержимое секции по ajax.</p>
';

#Permissions Descriptions
$lang['PermissionShowSectionsModule'] = 'Модуль "Секции": Показывать модуль';

#Params Help
$lang['ParamHelpName'] = '"Внутреннее имя" секции';
$lang['ParamHelpFormat'] = 'Формат представления данных. Возможные форматы: default, json';

#Module texts
$lang["SectionsList"] = 'Список секций';
$lang["Settings"] = 'Настройки';
$lang["AddSection"] = 'Добавить секцию';
$lang["EditSection"] = 'Редактировать секцию';
$lang["DeleteSection"] = 'Удалить секцию';
$lang["Placeholder"] = 'Тег для использования';
$lang["Name"] = 'Название';
$lang["Description"] = 'Описание';
$lang["InternalName"] = 'Внутреннее имя';
$lang["InternalNameFormat"] = 'Может содержать только латинские буквы, числа и подчёркивания. Это уникальное имя секции, которое используется в плейсхолдере.';
$lang["IsActive"] = 'Активная';
$lang["SetActive"] = 'Сделать активной';
$lang["SetInactive"] = 'Сделать неактивной';
$lang["Pages"] = 'Страницы';
$lang["DisplayConditions"] = 'Условия показа';
$lang["Properties"] = 'Свойства';
$lang["Content"] = 'Содержание';
$lang["FromDate"] = 'Дата начала';
$lang["ToDate"] = 'Дата окончания';
$lang["Save"] = 'Сохранить';
$lang["SaveAndExit"] = 'Сохранить и выйти';
$lang["Cancel"] = 'Отменить';
$lang["SectionDateRange"] = 'Активен только в период';
$lang["from"] = 'с';
$lang["to"] = 'по';
$lang["NoWysiwyg"] = 'Отключить визуальный редактор в этой секции';
$lang["ShowOnPages"] = 'Показывать на следующих страницах';
$lang["NotToShowOnPages"] = 'Не показывать на следующих страницах';
$lang["ShowOn"] = 'Показывать только на';
$lang["NotToShowOn"] = 'Не показывать только на';

#Confirms
$lang["ConfirmSectionEditCancel"] = 'Вы уверены, что хотите отменить редактирование секции и выйти?\n\nВНИМАНИЕ: Все несохранённые данные будут утеряны.';

#Errors
$lang["ErrInternalNameEmpty"] = 'Внутреннее имя не может быть пустым!';
$lang["ErrInternalNameInvalid"] = 'Внутренее имя недействительно. Допускаются только следующие символы: a-z, 0-9 и подчеркивание \'_\' !';
$lang["ErrWrongDateFormat"] = 'Неправильный формат или значение даты!';
$lang["ErrSectionNameExists"] = 'Секция с таким внутренним именем уже существует!';

#Messages
$lang["MsgSectionSaved"] = 'Секция успешно сохранена!';
$lang["MsgSectionDeleted"] = 'Секция успешно удалена!';

#Admin log
$lang['AuditSectionAdded'] = 'Добавлена новая секция "%s"';
$lang['AuditSectionUpdated'] = 'Обновлена секция "%s".';
$lang['AuditSectionSetActive'] = 'Секция "%s" установлена активной.';
$lang['AuditSectionSetInactive'] = 'Секция "%s" установлена неактивной.';

#Datepicker
$lang["Previous"] = 'Previous';
$lang["Next"] = 'Next';
$lang["January"] = 'Январь';
$lang["February"] = 'Февраль';  
$lang["March"] = 'Март';  
$lang["April"] = 'Апрель';  
$lang["May"] = 'Май';  
$lang["June"] = 'Июнь';  
$lang["July"] = 'Июль';  
$lang["August"] = 'Август';  
$lang["September"] = 'Сентябрь';  
$lang["October"] = 'Октябрь';  
$lang["November"] = 'Ноябрь';  
$lang["December"] = 'Декабрь';
$lang["JanuaryMin"] = 'Янв';  
$lang["FebruaryMin"] = 'Фев';  
$lang["MarchMin"] = 'Мар';  
$lang["AprilMin"] = 'Апр';  
$lang["MayMin"] = 'Май';  
$lang["JuneMin"] = 'Июн';  
$lang["JulyMin"] = 'Июл';  
$lang["AugustMin"] = 'Авг';  
$lang["SeptemberMin"] = 'Сен';  
$lang["OctoberMin"] = 'Окт';  
$lang["NovemberMin"] = 'Ноя';  
$lang["DecemberMin"] = 'Дек';
$lang["MondayMin"] = 'Пн';  
$lang["TuesdayMin"] = 'Вт';  
$lang["WednesdayMin"] = 'Ср';  
$lang["ThursdayMin"] = 'Чт';  
$lang["FridayMin"] = 'Пт';  
$lang["SaturdayMin"] = 'Сб';  
$lang["SundayMin"] = 'Вс';
$lang["Monday"] = 'Понедельник';  
$lang["Tuesday"] = 'Вторник';  
$lang["Wednesday"] = 'Среда';  
$lang["Thursday"] = 'Четверг';  
$lang["Friday"] = 'Пятница';  
$lang["Saturday"] = 'Суббота';  
$lang["Sunday"] = 'Воскресенье';
?>

==> Sections-1.0.2.zip: lang/ext/ru_RU.php <==
<?php
$lang['friendlyname'] = 'Секции';
$lang['postinstall'] = 'Модуль "Секции" успешно установлен!';
$lang['postuninstall'] = 'Модуль "Секции" успешно удалён!';
$lang['really_uninstall'] = 'Вы уверены, что хотите удалить модуль "Секции"?';
$lang['uninstalled'] = 'Удалён модуль "Секции".';
$lang['installed'] = 'Установлен модуль "Секции" - версия %s.';
$lang['moddescription'] = 'Секции - это блоки контента, которые вы можете размещать в своих шаблонах и страницах с помощью \'плейсхолдеров\'.';
$lang['help'] = '
<h3>Для чего нужен этот модуль?</h3>
<p>Данный модуль позволяет создавать секции, в которые Вы можете помещать любой контент, будь то просто текст или html-содержимое или js-код.</p>
<p>Вы можете вставить тег данного модуля в шаблон и при редактировании секции на вкладке "Условия показа" выбрать страницы на которых данная секция будет видна.</p>
<p>Это может быть полезно, если вы хотите показывать в одном и том же месте на странице разное содержание, но не хотите выносить этот блок в область контента страницы.</p>
<p>Также Вы можете выставить у секции дату начала показа и дату окончания показа. Выставление этих параметров будет означать, что секция будет отображаться только в заданном промежутке времени и Вам не нужно беспокоится о выключении тех или иных секций в определённые дни.</p>
<h3>Как использовать модуль?</h3>
<p>После создания секции вставьте плейсхолдер секции вида {Sections name=\'internal_name\'} в шаблон, в страницу или куда-либо ещё, где internal_name это "Внутреннее имя" секции и при просмотре на месте плейсхолдера будет содержимое данной секции.</p>
<h4>Условный показ</h4>
<h5>Выбор промежутка дат для показа</h5>
<p>Вы можете выбрать дату начала показа и дату окончания показа. В случае если оба числа выбраны, секция будет показываться только в данном промежутке дат.</p>
<h5>Выбор страниц для показа</h5>
<p>Если вы вставите секцию в шаблон, то по умолчанию она будет показываться на всех страницах у которых выбран данный шаблон. Однако, если при редактировании секции во вкладке "Условия показа" Вы выберете страницы на которых вы хотите видеть секцию, то она будет показываться только на этих страницах.</p>
<p>Также, для удобства, Вы можете наоборот выбрать те страницы на которых секция показываться не должна.</p>
<h3>Обработка тегов(плейсхолдеров) в контенте секции</h3>
<p>В контенте секции Вы можете использовать абсолютно любые тэги без каких-либо ограничений.</p>
<h3>Использование в JavaScript</h3>
<p>Использовать секции в JavaScript очень просто. Для этого нужно проделать всего несколько шагов.</p>
<ol>
<li>Создать шаблон в который поместить только тег {content}. К примеру его можно назвать "_system_".</li>
<li>Создать секцию, поместить в неё тот контент, который требуется получить через JavaScript.</li>
<li>Создать страницу и присвоить ей шаблон _system_. В качестве контента указать тег секции вида {Sections name=\'internal_name\' format=\'json\'}. Параметр \'format\' указывает в каком виде возвращать данные. Если указать json, то контент секции будет возвращён в json формате, если указать default, то контент секции будет возвращён в обычном html формате.</li>
</ol>
<p>Теперь Вы можете получить содержимое секции по ajax.</p>
';

#Permissions Descriptions
$lang['PermissionShowSectionsModule'] = 'Модуль "Секции": Показывать модуль';

#Params Help
$lang['ParamHelpName'] = '"Внутреннее имя" секции';
$lang['ParamHelpFormat'] = 'Формат представления данных. Возможные форматы: default, json';

#Module texts
$lang["SectionsList"] = 'Список секций';
$lang["Settings"] = 'Настройки';
$lang["AddSection"] = 'Добавить секцию';
$lang["EditSection"] = 'Редактировать секцию';
$lang["DeleteSection"] = 'Удалить секцию';
$lang["Placeholder"] = 'Тег для использования';
$lang["Name"] = 'Название';
$lang["Description"] = 'Описание';
$lang["InternalName"] = 'Внутреннее имя';
$lang["InternalNameFormat"] = 'Может содержать только латинские буквы, числа и подчёркивания. Это уникальное имя секции, которое используется в плейсхолдере.';
$lang["IsActive"] = 'Активная';
$lang["SetActive"] = 'Сделать активной';
$lang["SetInactive"] = 'Сделать неактивной';
$lang["Pages"] = 'Страницы';
$lang["DisplayConditions"] = 'Условия показа';
$lang["Properties"] = 'Свойства';
$lang["Content"] = 'Содержание';
$lang["FromDate"] = 'Дата начала';
$lang["ToDate"] = 'Дата окончания';
$lang["Save"] = 'Сохранить';
$lang["SaveAndExit"] = 'Сохранить и выйти';
$lang["Cancel"] = 'Отменить';
$lang["SectionDateRange"] = 'Активен только в период';
$lang["from"] = 'с';
$lang["to"] = 'по';
$lang["NoWysiwyg"] = 'Отключить визуальный редактор в этой секции';
$lang["ShowOnPages"] = 'Показывать на следующих страницах';
$lang["NotToShowOnPages"] = 'Не показывать на следующих страницах';
$lang["ShowOn"] = 'Показывать только на';
$lang["NotToShowOn"] = 'Не показывать только на';

#Confirms
$lang["ConfirmSectionEditCancel"] = 'Вы уверены, что хотите отменить редактирование секции и выйти?\n\nВНИМАНИЕ: Все несохранённые данные будут утеряны.';
$lang["ConfirmSectionDelete"] = 'Вы уверены, что хотите удалить данную секцию?';

#Errors
$lang["ErrInternalNameEmpty"] = 'Внутреннее имя не может быть пустым!';
$lang["ErrInternalNameInvalid"] = 'Внутренее имя недействительно. Допускаются только следующие символы: a-z, 0-9 и подчеркивание \'_\' !';
$lang["ErrWrongDateFormat"] = 'Неправильный формат или значение даты!';
$lang["ErrSectionNameExists"] = 'Секция с таким внутренним именем уже существует!';

#Messages
$lang["MsgSectionSaved"] = 'Секция успешно сохранена!';
$lang["MsgSectionDeleted"] = 'Секция успешно удалена!';

#Admin log
$lang['AuditSectionAdded'] = 'Добавлена новая секция "%s"';
$lang['AuditSectionUpdated'] = 'Обновлена секция "%s".';
$lang['AuditSectionSetActive'] = 'Секция "%s" установлена активной.';
$lang['AuditSectionSetInactive'] = 'Секция "%s" установлена неактивной.';

#Datepicker
$lang["Previous"] = 'Previous';
$lang["Next"] = 'Next';
$lang["January"] = 'Январь';
$lang["February"] = 'Февраль';  
$lang["March"] = 'Март';  
$lang["April"] = 'Апрель';  
$lang["May"] = 'Май';  
$lang["June"] = 'Июнь';  
$lang["July"] = 'Июль';  
$lang["August"] = 'Август';  
$lang["September"] = 'Сентябрь';  
$lang["October"] = 'Октябрь';  
$lang["November"] = 'Ноябрь';  
$lang["December"] = 'Декабрь';
$lang["JanuaryMin"] = 'Янв';  
$lang["FebruaryMin"] = 'Фев';  
$lang["MarchMin"] = 'Мар';  
$lang["AprilMin"] = 'Апр';  
$lang["MayMin"] = 'Май';  
$lang["JuneMin"] = 'Июн';  
$lang["JulyMin"] = 'Июл';  
$lang["AugustMin"] = 'Авг';  
$lang["SeptemberMin"] = 'Сен';  
$lang["OctoberMin"] = 'Окт';  
$lang["NovemberMin"] = 'Ноя';  
$lang["DecemberMin"] = 'Дек';
$lang["MondayMin"] = 'Пн';  
$lang["TuesdayMin"] = 'Вт';  
$lang["WednesdayMin"] = 'Ср';  
$lang["ThursdayMin"] = 'Чт';  
$lang["FridayMin"] = 'Пт';  
$lang["SaturdayMin"] = 'Сб';  
$lang["SundayMin"] = 'Вс';
$lang["Monday"] = 'Понедельник';  
$lang["Tuesday"] = 'Вторник';  
$lang["Wednesday"] = 'Среда';  
$lang["Thursday"] = 'Четверг';  
$lang["Friday"] = 'Пятница';  
$lang["Saturday"] = 'Суббота';  
$lang["Sunday"] = 'Воскресенье';
?>
